@@ -4,9 +4,9 @@
 
 #' Calculate the true positive rate
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param cutoff the threshold for the predicted outcome, default is 0.5
 #' @param digits the number of digits to round the result to, default is 2
@@ -18,8 +18,8 @@ get_tpr <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
   groups <- sort(unique(data[, group])) # Get sorted unique groups
 
   for (i in groups) {
-    tp <- sum(data[, outcome] == 1 & data[, group] == i & data[, probs] >= cutoff)
-    p <- sum(data[, outcome] == 1 & data[, group] == i)
+    tp <- sum(data[, outcome] == 1 & data[, group] == i & data[, probs] >= cutoff, na.rm=TRUE)
+    p <- sum(data[, outcome] == 1 & data[, group] == i, na.rm = TRUE)
     tpr <- c(tpr, round(tp / p, digits)) # Calculate TPR and add to vector
   }
 
@@ -29,9 +29,9 @@ get_tpr <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
 
 #' Calculate the false positive rate
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param cutoff the threshold for the predicted outcome, default is 0.5
 #' @param digits the number of digits to round the result to, default is 2
@@ -44,8 +44,8 @@ get_fpr <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
   for (i in groups) {
     fp <- sum(data[, outcome] == 0 &
       data[, group] == i &
-      data[, probs] >= cutoff)
-    n <- sum(data[, outcome] == 0 & data[, group] == i)
+      data[, probs] >= cutoff, na.rm = TRUE)
+    n <- sum(data[, outcome] == 0 & data[, group] == i, na.rm=TRUE)
     fpr <- c(fpr, round(fp / n, digits))
   }
   return(fpr)
@@ -53,9 +53,9 @@ get_fpr <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
 
 #' Calculate the probability of positive prediction
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param cutoff the threshold for the predicted outcome, default is 0.5
 #' @param digits the number of digits to round the result to, default is 2
@@ -68,9 +68,10 @@ get_ppr <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
   for (i in groups) {
     pp <- sum(
       data[, group] == i &
-        data[, probs] >= cutoff
+        data[, probs] >= cutoff,
+      na.rm = TRUE
     )
-    n <- sum(data[, group] == i)
+    n <- sum(data[, group] == i, na.rm=TRUE)
     ppr <- c(ppr, round(pp / n, digits))
   }
   return(ppr)
@@ -78,9 +79,9 @@ get_ppr <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
 
 #' Calculate the positive predictive value
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param cutoff the threshold for the predicted outcome, default is 0.5
 #' @param digits the number of digits to round the result to, default is 2
@@ -93,9 +94,9 @@ get_ppv <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
   for (i in groups) {
     tp <- sum(data[, outcome] == 1 &
       data[, group] == i &
-      data[, probs] >= cutoff)
+      data[, probs] >= cutoff, na.rm=TRUE)
     pp <- sum(data[, group] == i &
-      data[, probs] >= cutoff)
+      data[, probs] >= cutoff, na.rm=TRUE)
     ppv <- c(ppv, round(tp / pp, digits))
   }
   return(ppv)
@@ -103,9 +104,9 @@ get_ppv <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
 
 #' Calculate the negative predictive value
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param cutoff the threshold for the predicted outcome, default is 0.5
 #' @param digits the number of digits to round the result to, default is 2
@@ -118,9 +119,9 @@ get_npv <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
   for (i in groups) {
     tn <- sum(data[, outcome] == 0 &
       data[, group] == i &
-      data[, probs] < cutoff)
+      data[, probs] < cutoff, na.rm =TRUE)
     nn <- sum(data[, group] == i &
-      data[, probs] < cutoff)
+      data[, probs] < cutoff, na.rm = TRUE)
     npv <- c(npv, round(tn / nn, digits))
   }
   return(npv)
@@ -128,9 +129,9 @@ get_npv <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
 
 #' Calculate the accuracy
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param cutoff the threshold for the predicted outcome, default is 0.5
 #' @param digits the number of digits to round the result to, default is 2
@@ -141,13 +142,10 @@ get_acc <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
   acc <- c()
   groups <- sort(unique(data[, group]))
   for (i in groups) {
-    tp <- sum(data[, outcome] == 1 &
-      data[, group] == i &
-      data[, probs] >= cutoff)
-    tn <- sum(data[, outcome] == 0 &
-      data[, group] == i &
-      data[, probs] < cutoff)
-    p <- sum(data[, group] == i)
+    groups <- sort(unique(data[[group]]))
+    tp <- sum(data[, outcome] == 1 & data[,group] == i & data[,probs] >= cutoff, na.rm=TRUE)
+    tn <- sum(data[, outcome] == 0 & data[,group] == i & data[,probs] < cutoff, na.rm=TRUE)
+    p <- sum(data[,group] == i, na.rm = TRUE)
     acc <- c(acc, round((tp + tn) / p, digits))
   }
   return(acc)
@@ -155,9 +153,9 @@ get_acc <- function(data, outcome, group, probs, cutoff = 0.5, digits = 2) {
 
 #' Calculate the brier score
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param digits the number of digits to round the result to, default is 2
 #' @return a vector of brier score
@@ -168,16 +166,16 @@ get_brier_score <- function(data, outcome, group, probs, digits = 2) {
   groups <- sort(unique(data[, group]))
   for (i in groups) {
     sub_data <- data[data[, group] == i, ]
-    brier_score <- c(brier_score, round(mean((sub_data[, outcome] - sub_data[, probs])^2), digits))
+    brier_score <- c(brier_score, round(mean((sub_data[, outcome] - sub_data[, probs])^2, na.rm=TRUE), digits))
   }
   return(brier_score)
 }
 
 #' Calculate the the ratio of false negative to false positive
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param cutoff the threshold for the predicted outcome, default is 0.5
 #' @param digits the number of digits to round the result to, default is 2
@@ -191,9 +189,9 @@ get_err_ratio <- function(data, outcome, group, probs, cutoff = 0.5,
   for (i in groups) {
     sub_data <- data[data[, group] == i, ]
     fp <- sum(sub_data[, outcome] == 0 &
-      sub_data[, probs] >= cutoff)
+      sub_data[, probs] >= cutoff, na.rm =TRUE)
     fn <- sum(sub_data[, outcome] == 1 &
-      sub_data[, probs] < cutoff)
+      sub_data[, probs] < cutoff, na.rm =TRUE)
     err_ratio <- c(err_ratio, round(fn / fp, digits))
   }
   return(err_ratio)
@@ -201,9 +199,9 @@ get_err_ratio <- function(data, outcome, group, probs, cutoff = 0.5,
 
 #' Calculate the average predicted probability
 #' @param data Data frame containing the outcome, predicted outcome, and
-#' sensitive attribute
+#' protected attribute
 #' @param outcome the name of the outcome variable, it must be binary
-#' @param group the name of the sensitive attribute
+#' @param group the name of the protected attribute
 #' @param probs the name of the predicted outcome variable
 #' @param digits the number of digits to round the result to, default is 2
 #' @return a vector of average predicted probability
@@ -214,7 +212,7 @@ get_avg_prob <- function(data, outcome, group, probs, digits = 2) {
   groups <- sort(unique(data[, group]))
   for (i in groups) {
     sub_data <- data[data[, group] == i, ]
-    avg_prob <- c(avg_prob, round(mean(sub_data[, probs]), digits))
+    avg_prob <- c(avg_prob, round(mean(sub_data[, probs],na.rm=TRUE), digits))
   }
   return(avg_prob)
 }
